from __future__ import annotations

import ckan.plugins.toolkit as tk


CONF_TEST_CONN = "ckanext.mailcraft.test_conn_on_startup"
DEF_TEST_CONN = False

CONF_CONN_TIMEOUT = "ckanext.mailcraft.conn_timeout"
DEF_CONN_TIMEOUT = 10

CONF_STOP_OUTGOING = "ckanext.mailcraft.stop_outgoing_emails"
DEF_STOP_OUTGOING = False

CONF_MAIL_PER_PAGE = "ckanext.mailcraft.mail_per_page"
DEF_MAIL_PER_PAGE = 20

CONF_REDIRECT_EMAILS_TO = "ckanext.mailcraft.redirect_emails_to"


def get_conn_timeout() -> int:
    """Return a timeout for an SMTP connection"""
    return tk.asint(tk.config.get(CONF_CONN_TIMEOUT) or DEF_CONN_TIMEOUT)


def is_startup_conn_test_enabled() -> bool:
    """Check do we want to check an SMTP conn on CKAN startup"""

    return tk.asbool(tk.config.get(CONF_TEST_CONN, DEF_TEST_CONN))


def stop_outgoing_emails() -> bool:
    """Check if we are stopping outgoing emails. In this case, we are only
    saving it to dashboard"""
    return tk.asbool(tk.config.get(CONF_STOP_OUTGOING, DEF_STOP_OUTGOING))


def get_mail_per_page() -> int:
    """Return a number of mails to show per page"""
    return tk.asint(tk.config.get(CONF_MAIL_PER_PAGE) or DEF_MAIL_PER_PAGE)


def get_redirect_email() -> str | None:
    """Redirect outgoing emails to a specified email"""
    return tk.config.get(CONF_REDIRECT_EMAILS_TO)
